/*
 *  Copyright (C) 2000  Mel Gorman (mel@skynet.ie)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
                
#ifndef __VQF_H
#define __VQF_H

/* Some include files from TwinVQ */
#include "twinvq.h"
#include "tvqdec.h"
#include "bfile.h"
#include "bstream.h"
#include "Chunk.h"
#include "ChunkHelper.h"
#include "HeaderManager.h"

/* System include files */
#include <sys/stat.h>
#include <gtk/gtk.h>

#ifdef DEBUG
  #define TRACE(X) printf(X); fflush(NULL)
#else
  #define TRACE(X)
#endif

/* XMMS Plugin header */
#include "plugin.h"

/* XMMS Support Functions */
extern "C" 
{
  extern void xmms_usleep(gint usec);
  GtkWidget *xmms_show_message(gchar * title, gchar * text, gchar * button_text, gboolean modal, GtkSignalFunc button_action, gpointer action_data);
}

/* Struct to store information on VQF */ 
typedef struct
{
  /* Handle to file playing */
  BFILE *file;

  /* Is file playing or not */
  bool playing;

  /* Header information for the VQF */
  headerInfo header;

  /* Other information taken from it */
  int length;
  int bitsPerSample;
  int samplesPerSec;
  int numChannels;
  int frameSize;
  int seekTime;

  int totalFrames;
  int currentFrame;
  INDEX index;

} VQFFile;

/* Functions to export */
extern "C" {
	void    vqfInit         ();
	void    vqfAbout        ();
	int     vqfFile         (char *filename);
	void    vqfPlay         (char *filename);
	void    vqfStop         (void);
	void    vqfPause        (short p);
	void    vqfSeek         (int time);
	int     vqfGetTime      (void);
	void    vqfGetInfo      (char *filename, char **title, int *length);
	void    vqfInfoBox      (char *filename);
}

/* Fills the struct with information on the file */
int getSongInfo(char *filename, VQFFile *fileInfo, bool closeFile=true);

#endif
